"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFilms = exports.parseBirthPlace = exports.parseAge = exports.parseBirthday = exports.getPhoto = exports.getBio = exports.getBirthdayInfo = exports.getName = exports.getId = exports.getColorRating = void 0;
const global_helper_1 = require("./global.helper");
const getColorRating = (el) => {
    return (0, global_helper_1.parseColor)(el === null || el === void 0 ? void 0 : el.classNames.split(' ').pop());
};
exports.getColorRating = getColorRating;
const getId = (url) => {
    if (url) {
        return (0, global_helper_1.parseIdFromUrl)(url);
    }
    return null;
};
exports.getId = getId;
const getName = (el) => {
    return el.querySelector('h1').innerText.trim();
};
exports.getName = getName;
const getBirthdayInfo = (el) => {
    const text = el.querySelector('h1 + p').innerHTML.trim();
    const parts = text.split('\n');
    let birthday;
    let age;
    let birthPlace;
    if (parts.length) {
        const birthdayRow = parts.find((x) => x.includes('nar.'));
        const ageRow = parts.find((x) => x.includes('let)'));
        const birthPlaceRow = parts.find((x) => x.includes('<br>')); // Ugly but there is no other way to detect
        birthday = birthdayRow ? (0, exports.parseBirthday)(birthdayRow) : '';
        age = ageRow ? +(0, exports.parseAge)(ageRow) : null;
        birthPlace = birthPlaceRow ? (0, exports.parseBirthPlace)(birthPlaceRow) : '';
    }
    return { birthday, age, birthPlace };
};
exports.getBirthdayInfo = getBirthdayInfo;
const getBio = (el) => {
    return el.querySelector('.article-content p').text.trim().split('\n')[0].trim();
};
exports.getBio = getBio;
const getPhoto = (el) => {
    const image = el.querySelector('img').attributes.src;
    return (0, global_helper_1.addProtocol)(image);
};
exports.getPhoto = getPhoto;
const parseBirthday = (text) => {
    return text.replace(/nar./g, '').trim();
};
exports.parseBirthday = parseBirthday;
const parseAge = (text) => {
    return text.trim().replace(/\(/g, '').replace(/let\)/g, '').trim();
};
exports.parseAge = parseAge;
const parseBirthPlace = (text) => {
    return text.trim().replace(/<br>/g, '').trim();
};
exports.parseBirthPlace = parseBirthPlace;
const getFilms = (el) => {
    var _a;
    const filmNodes = (_a = el.querySelectorAll('.box')[0]) === null || _a === void 0 ? void 0 : _a.querySelectorAll('table tr');
    let yearCache;
    const films = filmNodes.map((filmNode) => {
        var _a, _b, _c;
        const id = (0, exports.getId)((_a = filmNode.querySelector('td.name .film-title-name')) === null || _a === void 0 ? void 0 : _a.attributes.href);
        const title = (_b = filmNode.querySelector('.name')) === null || _b === void 0 ? void 0 : _b.text.trim();
        const year = +((_c = filmNode.querySelector('.year')) === null || _c === void 0 ? void 0 : _c.text.trim());
        const colorRating = (0, exports.getColorRating)(filmNode.querySelector('.name .icon'));
        // Cache year from previous film because there is a gap between movies with same year
        if (year) {
            yearCache = +year;
        }
        if (id && title) {
            return {
                id,
                title,
                year: year || yearCache,
                colorRating
            };
        }
        return {};
    });
    // Remove empty objects
    const filmsUnique = films.filter((value) => Object.keys(value).length !== 0);
    return filmsUnique;
};
exports.getFilms = getFilms;
