import { parseColor, parseIdFromUrl } from './global.helper';
export const getColorRating = (el) => {
    return parseColor(el === null || el === void 0 ? void 0 : el.classNames.split(' ').pop());
};
export const getCinemaId = (el) => {
    var _a;
    const id = (_a = el === null || el === void 0 ? void 0 : el.id) === null || _a === void 0 ? void 0 : _a.split('-')[1];
    console.log('id', id);
    return +id;
};
export const getId = (url) => {
    if (url) {
        return parseIdFromUrl(url);
    }
    return null;
};
export const getName = (el) => {
    return el.querySelector('h1').innerText.trim();
};
export const getCoords = (el) => {
    const link = el === null || el === void 0 ? void 0 : el.querySelector('.box-header img[alt="Google Maps"]').closest('a').getAttribute('href');
    const coords = link.split('q=')[1].split(',');
    const [lat, lng] = coords;
    return { lat: +lat, lng: +lng };
};
export const getCinemaUrl = (el) => {
    var _a;
    return (_a = el.querySelector('.box-header .cinema-logo a')) === null || _a === void 0 ? void 0 : _a.attributes.href;
};
export const parseCinema = (el) => {
    const title = el.querySelector('.box-header h2').innerText.trim();
    const [city, name] = title.split(' - ');
    return { city, name };
};
export const getGroupedFilmsByDate = (el) => {
    const divs = el.querySelectorAll(':scope > div');
    const getDatesAndFilms = divs
        .map((_, index) => index)
        .filter((index) => index % 2 === 0)
        .map((index) => {
        const [date, films] = divs.slice(index, index + 2);
        const dateText = date === null || date === void 0 ? void 0 : date.innerText.trim();
        return { date: dateText, films: getFilms('', films) };
    });
    return getDatesAndFilms;
};
export const getFilms = (date, el) => {
    const filmNodes = el.querySelectorAll('.cinema-table tr');
    const films = filmNodes.map((filmNode) => {
        var _a, _b, _c, _d;
        const url = (_a = filmNode.querySelector('td.name h3 a')) === null || _a === void 0 ? void 0 : _a.attributes.href;
        const id = getId(url);
        const title = (_b = filmNode.querySelector('.name h3')) === null || _b === void 0 ? void 0 : _b.text.trim();
        const colorRating = getColorRating(filmNode.querySelector('.name .icon'));
        const showTimes = (_c = filmNode.querySelectorAll('.td-time')) === null || _c === void 0 ? void 0 : _c.map((x) => x.textContent.trim());
        const meta = (_d = filmNode.querySelectorAll('.td-title span')) === null || _d === void 0 ? void 0 : _d.map((x) => x.text.trim());
        return {
            id,
            title,
            url,
            colorRating,
            showTimes,
            meta: parseMeta(meta)
        };
    });
    return films;
};
export const parseMeta = (meta) => {
    const metaConvert = [];
    for (const element of meta) {
        if (element === 'T') {
            metaConvert.push('subtitles');
        }
        else if (element === 'D') {
            metaConvert.push('dubbing');
        }
        else {
            metaConvert.push(element);
        }
    }
    return metaConvert;
};
