import { addProtocol, parseColor, parseIdFromUrl } from './global.helper';
export const getColorRating = (el) => {
    return parseColor(el === null || el === void 0 ? void 0 : el.classNames.split(' ').pop());
};
export const getId = (url) => {
    if (url) {
        return parseIdFromUrl(url);
    }
    return null;
};
export const getName = (el) => {
    return el.querySelector('h1').innerText.trim();
};
export const getBirthdayInfo = (el) => {
    const text = el.querySelector('h1 + p').innerHTML.trim();
    const parts = text.split('\n');
    let birthday;
    let age;
    let birthPlace;
    if (parts.length) {
        const birthdayRow = parts.find((x) => x.includes('nar.'));
        const ageRow = parts.find((x) => x.includes('let)'));
        const birthPlaceRow = parts.find((x) => x.includes('<br>')); // Ugly but there is no other way to detect
        birthday = birthdayRow ? parseBirthday(birthdayRow) : '';
        age = ageRow ? +parseAge(ageRow) : null;
        birthPlace = birthPlaceRow ? parseBirthPlace(birthPlaceRow) : '';
    }
    return { birthday, age, birthPlace };
};
export const getBio = (el) => {
    return el.querySelector('.article-content p').text.trim().split('\n')[0].trim();
};
export const getPhoto = (el) => {
    const image = el.querySelector('img').attributes.src;
    return addProtocol(image);
};
export const parseBirthday = (text) => {
    return text.replace(/nar./g, '').trim();
};
export const parseAge = (text) => {
    return text.trim().replace(/\(/g, '').replace(/let\)/g, '').trim();
};
export const parseBirthPlace = (text) => {
    return text.trim().replace(/<br>/g, '').trim();
};
export const getFilms = (el) => {
    var _a;
    const filmNodes = (_a = el.querySelectorAll('.box')[0]) === null || _a === void 0 ? void 0 : _a.querySelectorAll('table tr');
    let yearCache;
    const films = filmNodes.map((filmNode) => {
        var _a, _b, _c;
        const id = getId((_a = filmNode.querySelector('td.name .film-title-name')) === null || _a === void 0 ? void 0 : _a.attributes.href);
        const title = (_b = filmNode.querySelector('.name')) === null || _b === void 0 ? void 0 : _b.text.trim();
        const year = +((_c = filmNode.querySelector('.year')) === null || _c === void 0 ? void 0 : _c.text.trim());
        const colorRating = getColorRating(filmNode.querySelector('.name .icon'));
        // Cache year from previous film because there is a gap between movies with same year
        if (year) {
            yearCache = +year;
        }
        if (id && title) {
            return {
                id,
                title,
                year: year || yearCache,
                colorRating
            };
        }
        return {};
    });
    // Remove empty objects
    const filmsUnique = films.filter((value) => Object.keys(value).length !== 0);
    return filmsUnique;
};
