var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { parse } from 'node-html-parser';
import { fetchPage } from '../fetchers';
import { getBoxMovies, getColorRating, getDescriptions, getDuration, getGenres, getGroup, getOrigins, getPoster, getPremieres, getRandomPhoto, getRating, getRatingCount, getTags, getTitle, getTitlesOther, getTrivia, getType, getVods, getYear } from '../helpers/movie.helper';
import { movieUrl } from '../vars';
export class MovieScraper {
    movie(movieId) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = movieUrl(+movieId);
            const response = yield fetchPage(url);
            const movieHtml = parse(response);
            const pageClasses = movieHtml.querySelector('.page-content').classNames.split(' ');
            const asideNode = movieHtml.querySelector('.aside-movie-profile');
            const movieNode = movieHtml.querySelector('.main-movie-profile');
            const jsonLd = movieHtml.querySelector('script[type="application/ld+json"]').innerText;
            this.buildMovie(+movieId, movieNode, asideNode, pageClasses, jsonLd);
            return this.film;
        });
    }
    buildMovie(movieId, el, asideEl, pageClasses, jsonLd) {
        this.film = {
            id: movieId,
            title: getTitle(el),
            year: getYear(jsonLd),
            duration: getDuration(jsonLd, el),
            descriptions: getDescriptions(el),
            genres: getGenres(el),
            type: getType(el),
            url: movieUrl(movieId),
            origins: getOrigins(el),
            colorRating: getColorRating(pageClasses),
            rating: getRating(asideEl),
            ratingCount: getRatingCount(asideEl),
            titlesOther: getTitlesOther(el),
            poster: getPoster(el),
            photo: getRandomPhoto(el),
            trivia: getTrivia(el),
            creators: {
                directors: getGroup(el, 'Režie'),
                writers: getGroup(el, 'Scénář'),
                cinematography: getGroup(el, 'Kamera'),
                music: getGroup(el, 'Hudba'),
                actors: getGroup(el, 'Hrají'),
                basedOn: getGroup(el, 'Předloha'),
                producers: getGroup(el, 'Produkce'),
                filmEditing: getGroup(el, 'Střih'),
                costumeDesign: getGroup(el, 'Kostýmy'),
                productionDesign: getGroup(el, 'Scénografie')
            },
            vod: getVods(asideEl),
            tags: getTags(asideEl),
            premieres: getPremieres(asideEl),
            related: getBoxMovies(asideEl, 'Související'),
            similar: getBoxMovies(asideEl, 'Podobné')
        };
    }
}
