var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { parse } from 'node-html-parser';
import { fetchPage } from '../fetchers';
import { parseIdFromUrl } from '../helpers/global.helper';
import { getAvatar, getUser, getUserRealName, getUserUrl } from '../helpers/search-user.helper';
import { getColorRating, getOrigins, getPoster, getTitle, getType, getUrl, getYear, parsePeople } from '../helpers/search.helper';
import { searchUrl } from '../vars';
export class SearchScraper {
    search(text) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = searchUrl(text);
            const response = yield fetchPage(url);
            const html = parse(response);
            const moviesNode = html.querySelectorAll('.main-movies article');
            const usersNode = html.querySelectorAll('.main-users article');
            const tvSeriesNode = html.querySelectorAll('.main-series article');
            return this.parseSearch(moviesNode, usersNode, tvSeriesNode);
        });
    }
    parseSearch(moviesNode, usersNode, tvSeriesNode) {
        const movies = [];
        const users = [];
        const tvSeries = [];
        moviesNode.map((m) => {
            const url = getUrl(m);
            const movie = {
                id: parseIdFromUrl(url),
                title: getTitle(m),
                year: getYear(m),
                url: `https://www.csfd.cz${url}`,
                type: getType(m),
                colorRating: getColorRating(m),
                poster: getPoster(m),
                origins: getOrigins(m),
                creators: {
                    directors: parsePeople(m, 'directors'),
                    actors: parsePeople(m, 'actors')
                }
            };
            movies.push(movie);
        });
        usersNode.map((m) => {
            const url = getUserUrl(m);
            const user = {
                id: parseIdFromUrl(url),
                user: getUser(m),
                userRealName: getUserRealName(m),
                avatar: getAvatar(m),
                url: `https://www.csfd.cz${url}`
            };
            users.push(user);
        });
        tvSeriesNode.map((m) => {
            const url = getUrl(m);
            const user = {
                id: parseIdFromUrl(url),
                title: getTitle(m),
                year: getYear(m),
                url: `https://www.csfd.cz${url}`,
                type: getType(m),
                colorRating: getColorRating(m),
                poster: getPoster(m),
                origins: getOrigins(m),
                creators: {
                    directors: parsePeople(m, 'directors'),
                    actors: parsePeople(m, 'actors')
                }
            };
            tvSeries.push(user);
        });
        const search = {
            movies: movies,
            users: users,
            tvSeries: tvSeries,
            creators: []
        };
        return search;
    }
}
